---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Check the develop branch**
Report to the combination of the develop branch of phonopy and the develop branch of phono3py.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error
